@@ -32,7 +32,8 @@ impl Provider for PythonProvider {
     fn detect(&self, app: &App, _env: &Environment) -> Result<bool> {
         let has_python = app.includes_file("main.py")
             || app.includes_file("requirements.txt")
-            || app.includes_file("pyproject.toml");
+            || app.includes_file("pyproject.toml")
+            || app.includes_file("Pipfile");
         Ok(has_python)
     }
 
@@ -122,6 +123,10 @@ impl PythonProvider {
             pkgs.append(&mut vec![Pkg::new("libmysqlclient.dev")]);
         }
 
+        if app.includes_file("Pipfile") {
+            pkgs.append(&mut vec![Pkg::new("pipenv")]);
+        }
+
         let mut setup = Phase::setup(Some(pkgs));
 
         // Many Python packages need some C headers to be available
@@ -171,6 +176,23 @@ impl PythonProvider {
 
             install_phase.add_cache_directory(PIP_CACHE_DIR.to_string());
 
+            return Ok(Some(install_phase));
+        } else if app.includes_file("Pipfile") {
+            // By default Pipenv creates an environment directory in some random location (for example `/root/.local/share/virtualenvs/app-4PlAip0Q`).
+            // `PIPENV_VENV_IN_PROJECT` tells it that there is an already activated `venv` environment, So Pipenv will use the same directory instead of creating new one (in our case it's `/app/.venv`)
+
+            let cmd = if app.includes_file("Pipfile.lock") {
+                "PIPENV_VENV_IN_PROJECT=1 pipenv install --deploy"
+            } else {
+                "PIPENV_VENV_IN_PROJECT=1 pipenv install --skip-lock"
+            };
+
+            let cmd = format!("{} && {} && {}", create_env, activate_env, cmd);
+            let mut install_phase = Phase::install(Some(cmd));
+
+            install_phase.add_path(format!("{}/bin", env_loc));
+            install_phase.add_cache_directory(PIP_CACHE_DIR.to_string());
+
             return Ok(Some(install_phase));
         }
 
@@ -207,12 +229,8 @@ impl PythonProvider {
 
     fn is_django(app: &App, _env: &Environment) -> Result<bool> {
         let has_manage = app.includes_file("manage.py");
-        let imports_django = vec!["requirements.txt", "pyproject.toml"].iter().any(|f| {
-            app.read_file(f)
-                .unwrap_or_default()
-                .to_lowercase()
-                .contains("django")
-        });
+        let imports_django = PythonProvider::uses_dep(app, "django")?;
+
         Ok(has_manage && imports_django)
     }
 
@@ -254,6 +272,15 @@ impl PythonProvider {
         bail!("Failed to find django application name!")
     }
 
+    fn parse_pipfile_python_version(file_content: &str) -> Result<Option<String>> {
+        let matches = Regex::new("(python_version|python_full_version) = ['|\"]([0-9|.]*)")?
+            .captures(file_content);
+
+        Ok(matches
+            .filter(|m| m.len() > 2)
+            .map(|m| m.get(2).unwrap().as_str().to_string()))
+    }
+
     fn get_nix_python_package(app: &App, env: &Environment) -> Result<Pkg> {
         // Fetch python versions into tuples with defaults
         fn as_default(v: Option<Match>) -> &str {
@@ -271,6 +298,9 @@ impl PythonProvider {
             custom_version = Some(app.read_file(".python-version")?);
         } else if app.includes_file("runtime.txt") {
             custom_version = Some(app.read_file("runtime.txt")?);
+        } else if app.includes_file("Pipfile") {
+            let file_content = &app.read_file("Pipfile")?;
+            custom_version = PythonProvider::parse_pipfile_python_version(file_content)?;
         }
 
         // If it's still none, return default
@@ -353,19 +383,18 @@ impl PythonProvider {
     }
 
     fn uses_dep(app: &App, dep: &str) -> Result<bool> {
-        let requirements_usage = app.includes_file("requirements.txt")
-            && app
-                .read_file("requirements.txt")?
-                .to_lowercase()
-                .contains(dep);
+        let is_used = vec!["requirements.txt", "pyproject.toml", "Pipfile"]
+            .iter()
+            .any(|f| {
+                app.includes_file(f)
+                    && app
+                        .read_file(f)
+                        .unwrap_or_default()
+                        .to_lowercase()
+                        .contains(dep)
+            });
 
-        let pyproject_usage = app.includes_file("pyproject.toml")
-            && app
-                .read_file("pyproject.toml")?
-                .to_lowercase()
-                .contains(dep);
-
-        Ok(requirements_usage || pyproject_usage)
+        Ok(is_used)
     }
 }
 
@@ -388,6 +417,26 @@ mod test {
         Ok(())
     }
 
+    #[test]
+    fn test_pipfile_python_version() -> Result<()> {
+        let file_content = "\npython_version = '3.11'\n";
+        let custom_version = PythonProvider::parse_pipfile_python_version(file_content)?.unwrap();
+
+        assert_eq!(custom_version, "3.11");
+
+        Ok(())
+    }
+
+    #[test]
+    fn test_pipfile_python_full_version() -> Result<()> {
+        let file_content = "\npython_full_version = '3.11.0'\n";
+        let custom_version = PythonProvider::parse_pipfile_python_version(file_content)?.unwrap();
+
+        assert_eq!(custom_version, "3.11.0");
+
+        Ok(())
+    }
+
     #[test]
     fn test_custom_version() -> Result<()> {
         assert_eq!(
